"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Search = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const __1 = require("../../../");
const react_select_1 = __importDefault(require("react-select"));
const react_1 = require("react");
const store_1 = require("../../../store");
const material_1 = require("@mui/material");
const Search = () => {
    const theme = (0, material_1.useTheme)();
    const textFieldRef = (0, react_1.useRef)();
    const [value, setValue] = (0, react_1.useState)("");
    const [results, setResults] = (0, react_1.useState)([]);
    const [loading, setLoading] = (0, react_1.useState)(false);
    const [focused, setFocused] = (0, react_1.useState)(false);
    const appContext = (0, store_1.useAppContext)();
    const configuration = (0, store_1.useConfiguration)();
    const searchResults = (0, react_1.useCallback)(() => __awaiter(void 0, void 0, void 0, function* () {
        var _a;
        if (value.length === 0) {
            setResults([]);
            return;
        }
        setLoading(true);
        try {
            const resp = yield ((_a = configuration.searchProvider) === null || _a === void 0 ? void 0 : _a.search(value, appContext));
            setResults(resp || []);
        }
        catch (e) {
            console.log(e);
            setResults([]);
        }
        setLoading(false);
    }), [value, appContext, configuration]);
    const onChange = (0, react_1.useCallback)((val, action) => {
        if (action.action !== "input-blur" && action.action !== "menu-close") {
            setValue(val);
        }
    }, []);
    const focusSearch = (0, react_1.useCallback)((e) => {
        if (e.ctrlKey && e.shiftKey && e.keyCode === 70) {
            textFieldRef.current && textFieldRef.current.focus();
            e.stopPropagation();
        }
    }, []);
    (0, react_1.useEffect)(() => {
        window.addEventListener("keydown", focusSearch);
        return () => window.removeEventListener("keydown", focusSearch);
    }, [focusSearch]);
    (0, react_1.useEffect)(() => {
        searchResults();
    }, [searchResults]);
    return ((0, jsx_runtime_1.jsx)("div", { children: (0, jsx_runtime_1.jsx)(react_select_1.default, { ref: textFieldRef, isSearchable: true, value: value, onChange: (option, e) => { var _a; return (_a = configuration.searchProvider) === null || _a === void 0 ? void 0 : _a.onItemSelected(option, appContext); }, noOptionsMessage: () => "No result found", blurInputOnSelect: true, inputValue: value, onInputChange: (value, action) => onChange(value, action), options: results, formatOptionLabel: (option, context) => {
                var _a, _b;
                if ((_a = configuration.searchProvider) === null || _a === void 0 ? void 0 : _a.renderSearchItem) {
                    return (_b = configuration.searchProvider) === null || _b === void 0 ? void 0 : _b.renderSearchItem(option, appContext);
                }
            }, getOptionValue: (option) => value, menuIsOpen: value.length > 0 && focused, placeholder: "Search...", isLoading: loading, onFocus: () => setFocused(true), onBlur: () => setFocused(false), styles: {
                control: (base) => (Object.assign(Object.assign({}, base), { width: focused ? 400 : 200, backgroundColor: focused ? '#00000066' : '#00000033', border: '0', height: 30, minHeight: 30, transition: 'all ease 400ms', 
                    // color: '#FFF',
                    boxShadow: 'none', fontSize: 14 })),
                placeholder: (base) => (Object.assign(Object.assign({}, base), { color: '#FFFFFF66', lineHeight: '26px' })),
                container: (base) => (Object.assign(Object.assign({}, base), { border: 'none' })),
                dropdownIndicator: (base) => ({
                    height: 30
                }),
                input: (base) => (Object.assign(Object.assign({}, base), { color: '#FFF' })),
                option: (base, state) => (Object.assign(Object.assign({}, base), { color: 'initial', backgroundColor: state.isFocused ? theme === null || theme === void 0 ? void 0 : theme.palette.background.default : 'initial', padding: 0 })),
            }, components: {
                DropdownIndicator: (props) => ((0, jsx_runtime_1.jsx)("div", Object.assign({ style: { padding: '2px 5px 0px' } }, { children: (0, jsx_runtime_1.jsx)(__1.WIcon, { icon: "search", style: { color: '#FFFFFF66' } }) }))),
                IndicatorSeparator: () => null,
                LoadingIndicator: (props) => ((0, jsx_runtime_1.jsx)("div", Object.assign({ style: { padding: '2px 5px 0px' } }, { children: (0, jsx_runtime_1.jsx)(__1.WCircularProgress, { size: 22, style: { color: '#FFFFFFCC' } }) })))
            } }) }));
};
exports.Search = Search;
